==> projectx-sdk-1.0.58-sources.jar: cn/com/duiba/projectx/sdk/component/grade/GradeApi.java <==
package cn.com.duiba.projectx.sdk.component.grade;

import cn.com.duiba.projectx.sdk.UserRequestApi;
import cn.com.duiba.projectx.sdk.component.base.PrizeResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeConfigResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeItemConfig;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeQueryConfigResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeSpProduce;

import java.util.List;
import java.util.Map;

public interface GradeApi extends UserRequestApi {

    /**
     * 获取等级配置
     *  1. 查询配置
     *  2. 有埋点日志处理
     *
     * @param playwayId 玩法ID
     * @return
     */
    GradeQueryConfigResult queryGradeConfigV2(String playwayId);

    /**
     * 获取等级配置
     *
     * @param playwayId 玩法ID
     * @return
     */
    Map<Integer, GradeItemConfig> queryMapGradeConfigItem(String playwayId);

    /**
     * 获取等级配置
     *  1. 查询配置
     *  2. 有埋点日志处理
     *
     * @param playwayId 玩法ID
     * @return
     */
    List<GradeConfigResult> queryGradeConfig(String playwayId);

    /**
     * 获取用户当前等级的货币产出
     *
     * @param playwayId 玩法ID
     * @return
     */
    Map<String, GradeSpProduce> getGradeSpProduce(String playwayId, String userId);

    /**
     * 提交经验值
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @param score 经验值
     *              必须大于0
     * @return
     */
    GradeResult submitScore(String playwayId, String userId, int score);

    /**
     * 发奖
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @param gradeId 等级ID
     * @return
     */
    PrizeResult sendPrize(String playwayId, String userId, Integer gradeId);

    /**
     * 重置等级并发奖
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @return
     */
    PrizeResult resetAndSendPrize(String playwayId, String userId, Integer gradeId);

    /**
     * 查询等级
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @return
     */
    GradeResult queryGrade(String playwayId, String userId);

    /**
     * 是否最大等级
     * @param playwayId
     * @param userId
     * @return
     */
    boolean isMaxGrade(String playwayId, String userId);

    /**
     * 重置等级
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @return
     */
    GradeResult resetGrade(String playwayId, String userId);
}

==> projectx-sdk-1.0.77-20210601.093324-6-sources.jar: cn/com/duiba/projectx/sdk/component/grade/GradeApi.java <==
package cn.com.duiba.projectx.sdk.component.grade;

import cn.com.duiba.projectx.sdk.UserRequestApi;
import cn.com.duiba.projectx.sdk.component.base.PrizeResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeConfigResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeItemConfig;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeQueryConfigResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeResult;
import cn.com.duiba.projectx.sdk.component.grade.dto.GradeSpProduce;

import java.util.List;
import java.util.Map;

public interface GradeApi extends UserRequestApi {

    /**
     * 获取等级配置
     *  1. 查询配置
     *  2. 有埋点日志处理
     *
     * @param playwayId 玩法ID
     * @return
     */
    GradeQueryConfigResult queryGradeConfigV2(String playwayId);

    /**
     * 获取等级配置
     *
     * @param playwayId 玩法ID
     * @return
     */
    Map<Integer, GradeItemConfig> queryMapGradeConfigItem(String playwayId);

    /**
     * 获取等级配置
     *  1. 查询配置
     *  2. 有埋点日志处理
     *
     * @param playwayId 玩法ID
     * @return
     */
    List<GradeConfigResult> queryGradeConfig(String playwayId);

    /**
     * 获取用户当前等级的货币产出
     *
     * @param playwayId 玩法ID
     * @return
     */
    Map<String, GradeSpProduce> getGradeSpProduce(String playwayId, String userId);

    /**
     * 提交经验值
     *  ⚠️ 接口内部不作单用户高刷处理，由业务方决定
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @param score 经验值
     *              必须大于0
     * @return
     */
    GradeResult submitScore(String playwayId, String userId, int score);

    /**
     * 发奖
     *  ⚠️ 接口内部不作单用户高刷处理，由业务方决定
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @param gradeId 等级ID
     * @return
     */
    PrizeResult sendPrize(String playwayId, String userId, Integer gradeId);

    /**
     * 重置等级并发奖
     *  ⚠️ 接口内部不作单用户高刷处理，由业务方决定
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @return
     */
    PrizeResult resetAndSendPrize(String playwayId, String userId, Integer gradeId);

    /**
     * 查询等级
     *  ⚠️ 接口内部不作单用户高刷处理，由业务方决定
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @return
     */
    GradeResult queryGrade(String playwayId, String userId);

    /**
     * 是否最大等级
     * @param playwayId
     * @param userId
     * @return
     */
    boolean isMaxGrade(String playwayId, String userId);

    /**
     * 重置等级
     *  ⚠️ 接口内部不作单用户高刷处理，由业务方决定
     *
     * @param playwayId 玩法ID
     * @param userId 用户ID
     * @return
     */
    GradeResult resetGrade(String playwayId, String userId);
}
